//  File NXC_Explr_Laps04.h
//  Created by: hdrake, TabbyCat Robots      2011Jul21

#ifndef _NXC_EXPLR_LAPS04_H
#define _NXC_EXPLR_LAPS04_H

//  *******************************
//  #defines
//  *******************************

//  Following is the number of forward speeds for the robot.  It is used to
//  set the size of the arrays of variables related to various speeds.
#define NUM_OF_SPEED_SETTINGS                6


//  Following are define where on the roadway, the robot is located.

#define ROADWAY_SUBTYPE_RACING_LINE        21
#define ROADWAY_SUBTYPE_TIGHT_CURVE        22
#define ROADWAY_SUBTYPE_PASSING_CURVE      23
#define ROADWAY_SUBTYPE_PIT_ENTANCE        24
#define ROADWAY_SUBTYPE_PIT_EXIT           25
#define ROADWAY_SUBTYPE_PIT_LANE           26
#define ROADWAY_SUBTYPE_PIT_STALL          27
#define ROADWAY_SUBTYPE_STARTING_GRID      28
#define ROADWAY_SUBTYPE_STAGING_AREA       29  //  Area for line contrast discover.

#define PIT_STALL_LOCATION_NOT_DEFINED      0
#define PIT_STALL_LOCATION_RIGHT            1
#define PIT_STALL_LOCATION_LEFT             2


//  Following are lap numbers.  Yes, simple, but make code more readable.
#define LAP_01    1
#define LAP_02    2
#define LAP_03    3
#define LAP_04    4
#define LAP_05    5


//  Following are possible values, for whether a robot should use
//  passing lanes.
//  One variable using these values is the global unsigned char
//  use_passing_lanes, usually initiallized in the W***_kemmel_init() function.
#define NEVER_USE_PASSING_LANES                        0
#define USE_ANY_ALL_LEFT_PASSING_LANES                 1
#define USE_ANY_ALL_RIGHT_PASSING_LANES                2
#define USE_ANY_ALL_LEFT_OR_RIGHT_PASSING_LANES        3
#define USE_ANY_ALL_STRAIGHT_PASSING_LANES             4
#define USE_ANY_ALL_LEFT_OR_STRAIGHT_PASSING_LANES     5
#define USE_ANY_ALL_RIGHT_OR_STRAIGHT_PASSING_LANES    6
#define USE_ANY_ALL_PASSING_LANES                      7


//  Following are for actions to be taken, based on detected roadway color
#define NO_ACTION_SET             0
#define NO_DET_COLOR_CHG          1
#define STD_LINE_FOLLOW           2
#define MAX_SPEED_LINE_FOLLOW     3
#define PIT_LANE_LINE_FOLLOW      4

#define LANE_CHG_RIGHT            5
#define LANE_CHG_LEFT             6
#define LANE_CHG_STRAIGHT         7

#define ENTER_PIT_LANE_RIGHT      8
#define ENTER_PIT_LANE_LEFT       9
#define ENTER_PIT_LANE_STRAIGHT  10

#define ENTER_PIT_STALL_RIGHT    11
#define ENTER_PIT_STALL_LEFT     12

#define STOP_IN_PIT_STALL        13

#define SPEED_SUBSCRIPT_CHANGE   14

//  Color marker codes
#define BLACK_BLUE_ACTION_CODE     12  //  If roadway_subtype == ROADWAY_SUBTYPE_PIT_LANE,
                                       //  pit stall entrance for car having
                                       //  car_id == CAR_COLOR_BLUE.
                                       //  Precursor for 2 color code.
#define BLACK_GREEN_ACTION_CODE    13  //  If Accelerate - increment 1 speed_subscript,
                                       //  use bc_gain for straight, and precursor
                                       //  for 2 color code.
#define BLACK_RED_ACTION_CODE      15  //  Brake - use bc_gain for corner, and
                                       //  precursor for 2 color code.
                                       //  If in pit lane and if speed subscript ==
                                       //  PIT_LANE_SPEED_SUBSCRIPT, then precursor
                                       //  for 2 color code.
#define BLACK_YELLOW_ACTION_CODE   14  //  Precursor for 2 color code.

//  Move BLUE_GREEN and BLUE_RED to highway .h file.
#define BLUE_GREEN_ACTION_CODE     23  //  Lane change to right, or pit entrance on right.
#define BLUE_YELLOW_ACTION_CODE    24  //  Lane change straight, or pit entrance straight.
#define BLUE_RED_ACTION_CODE       25  //  Lane change to left, or pit entrance on left.

#define GREEN_BLUE_ACTION_CODE     32  //  Currently not used.
#define GREEN_YELLOW_ACTION_CODE   34  //  Currently not used.
#define GREEN_RED_ACTION_CODE      35  //  Exit test mode.

#define YELLOW_BLUE_ACTION_CODE    42  //  Very slow curve ahead.
#define YELLOW_GREEN_ACTION_CODE   43  //  Pit entrance ahead.
#define YELLOW_RED_ACTION_CODE     45  //  Start / finish line.

#define RED_BLUE_ACTION_CODE       52  //  Currently not used.
#define RED_GREEN_ACTION_CODE      53  //  Enter test mode.
#define RED_YELLOW_ACTION_CODE     54  //  Currently not used.


//  Stop and stay stopped.


#endif  //  End of  -  #ifndef _NXC_EXPLR_LAPS04_H

//  End File NXC_Explr_Laps04.h

